@@ -227,6 +227,8 @@ class Builder():
     print "Build complete!"
 
   def getBinary(self, revision):
+    #Return path of binary for a given changeset
+    #mozbuildserver uses this to build revisions
     self.build(changeset=revision)
 
     #run make package
@@ -236,22 +238,23 @@ class Builder():
     print "Binary build successful!"
 
     binary = None
+    renamedBinary = None
     distFolder = os.path.join(self.repoPath,"obj-ff-dbg","dist")
     #return path to package
     if sys.platform == "darwin":
         binary = glob.glob(distFolder+"/firefox-*.dmg")[0]
         renamedBinary = str(revision[:8]) + ".dmg" #Don't want the filename to be too long :)
-        print renamedBinary + " is binary"
     elif sys.platform == "linux2":
-        binary = None
-        renamedBinary = None
+        binary = glob.glob(distFolder+"/firefox-*.tar.gz")[0]
+        renamedBinary = str(revision[:8]) + ".tar.gz"
     elif sys.platform == "win32" or sys.platform == "cygwin":
-        binary = None
-        renamedBinary = None
+        binary = glob.glob(distFolder+"/firefox-*.zip")[0]
+        renamedBinary = str(revision[:8]) + ".zip"
     else:
       print "ERROR: This platform is unsupported."
       quit()
 
+    print renamedBinary + " is the binary:"
     if binary != None:
         #print "Move binary from " + binary
         #print " to " + os.path.join(self.shellCacheDir,renamedBinary)
@@ -262,10 +265,10 @@ class Builder():
         except:
             pass
 
-        shutil.move(binary, os.path.join(self.shellCacheDir,renamedBinary))
+        shutil.move(binary, os.path.join(self.shellCacheDir,"builds",renamedBinary))
 
         #Return binary path
-        return os.path.join(self.shellCacheDir,renamedBinary)
+        return (os.path.join(self.shellCacheDir,"builds",renamedBinary), renamedBinary)
 
     print "ERROR: Binary not found."
     quit()
